serviceUrl property
The URL of the Calljmp service endpoint.
This URL is used for all service-related API calls including database operations, user management, and custom endpoints.
Implementation
final String serviceUrl;
The URL of the Calljmp service endpoint.
This URL is used for all service-related API calls including database operations, user management, and custom endpoints.
final String serviceUrl;