SignalDatabaseDelete class

Database delete message

Inheritance

Constructors

SignalDatabaseDelete({required String id, required String topic, required List<SignalDatabaseRowId> rowIds})
const

Properties

eventType → SignalDatabaseEventType
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
rowIds → List<SignalDatabaseRowId>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic → String
finalinherited
type → SignalMessageType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited