SignalDatabaseMessage class abstract

Base class for database-specific data messages

Inheritance
Implementers

Constructors

SignalDatabaseMessage({required String id, required String topic, required SignalDatabaseEventType eventType})
const

Properties

eventType → SignalDatabaseEventType
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic → String
final
type → SignalMessageType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited