SignalDatabaseSubscribe class

Database subscribe message

Inheritance

Constructors

SignalDatabaseSubscribe({required String id, required String topic, List<String>? fields, Map<String, dynamic>? filter})
const

Properties

fields → List<String>?
finalinherited
filter → Map<String, dynamic>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic → String
finalinherited
type → SignalMessageType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited